@@ -4,19 +4,14 @@
 preview image on terminal | At present, only iTerm under MacOS is available,
 you need to install imgcat library by yourself
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-from .. import qs_default_console, qs_console_width
-from .. import prompt, user_lang, force_show_img, qs_config
+from .. import qs_default_console, qs_console_width, requirePackage, qs_default_status
+from .. import _ask, user_lang, force_show_img, qs_config
 import math
 import base64
 import sys
 import os
 import struct
 import io
-import subprocess
 
 # 记录强制显示状态，避免重复询问
 force_show_option = False
@@ -60,9 +55,7 @@ def get_image_shape(buf):
         b.write(buf)
 
         try:
-            from PIL import Image
-
-            im = Image.open(b)
+            im = requirePackage("PIL", "Image", "Pillow").open(b)
             return im.width, im.height
         except (IOError, OSError) as ex:
             # PIL.Image.open throws an error -- probably invalid byte input are given
@@ -96,7 +89,7 @@ def _isinstance(obj, module, clsname):
         return False
 
 
-def to_content_buf(data):
+def to_content_buf(data, fmt="png"):
     # TODO: handle 'stream-like' data efficiently, rather than storing into RAM
 
     if isinstance(data, bytes):
@@ -125,18 +118,11 @@ def to_content_buf(data):
                 "but given shape: {}".format(im.shape)
             )
 
-        try:
-            from PIL import Image
-        except ImportError as e:
-            raise ImportError(
-                e.msg
-                + "\nTo draw numpy arrays, we require Pillow. "
-                + "(pip install Pillow)"
-            )  # TODO; reraise
-
         with io.BytesIO() as buf:
             # mode: https://pillow.readthedocs.io/en/4.2.x/handbook/concepts.html#concept-modes
-            Image.fromarray(im, mode=mode).save(buf, format="png")
+            requirePackage("PIL", "Image", "Pillow").fromarray(im, mode=mode).save(
+                buf, format=fmt
+            )
             return buf.getvalue()
 
     elif _isinstance(data, "torch", "Tensor"):
@@ -147,7 +133,7 @@ def to_content_buf(data):
 
         with io.BytesIO() as buf:
             requirePackage("torchvision", "transforms").ToPILImage()(im).save(
-                buf, format="png"
+                buf, format=fmt
             )
             return buf.getvalue()
 
@@ -160,7 +146,7 @@ def to_content_buf(data):
         img = data
 
         with io.BytesIO() as buf:
-            img.save(buf, format="png")
+            img.save(buf, format=fmt)
             return buf.getvalue()
 
     elif _isinstance(data, "matplotlib.figure", "Figure"):
@@ -179,14 +165,8 @@ def to_content_buf(data):
         raise TypeError("Unsupported type : {}".format(type(data)))
 
 
-def get_tty_size():
-    with open("/dev/tty") as tty:
-        rows, columns = subprocess.check_output(["stty", "size"], stdin=tty).split()
-    return int(rows), int(columns)
-
-
 def real_height(buf, pixels_per_line=int(qs_config.basicSelect("terminal_font_size"))):
-    im_width, im_height = get_image_shape(buf)
+    _, im_height = get_image_shape(buf)
     if im_height:
         assert pixels_per_line > 0
         height = (im_height + (pixels_per_line - 1)) // pixels_per_line
@@ -194,8 +174,7 @@ def real_height(buf, pixels_per_line=int(qs_config.basicSelect("terminal_font_si
         # automatically limit height to the current tty,
         # otherwise the image will be just erased
         try:
-            tty_height, _ = get_tty_size()
-            return max(1, min(height, tty_height - 9))
+            return max(1, min(height, qs_default_console.height - 9))
         except OSError:
             # may not be a terminal
             pass
@@ -204,7 +183,14 @@ def real_height(buf, pixels_per_line=int(qs_config.basicSelect("terminal_font_si
         return 10
 
 
-def imgcat(buf, width=None, height=None, preserve_aspect_ratio=True, fp=None):
+def imgcat(
+    buf,
+    width=None,
+    height=None,
+    preserve_aspect_ratio=True,
+    fp=None,
+    force_show: bool = False,
+):
     """
     Print image on terminal (iTerm2).
 
@@ -239,6 +225,13 @@ def imgcat(buf, width=None, height=None, preserve_aspect_ratio=True, fp=None):
         fp.write(CSI + str(height).encode() + b"F")  # PEP-461
         fp.write(TMUX_WRAP_ST + b"\033")
 
+    is_iterm2 = "ITERM_SESSION_ID" in os.environ
+
+    if not is_iterm2 and not force_show:
+        raise RuntimeError(
+            "This function is only supported in iTerm2. "
+            "Please set `force_show=True` to force show the image."
+        )
     # now starts the iTerm2 file transfer protocol.
     fp.write(OSC)
     fp.write(b"1337;File=inline=1")
@@ -274,7 +267,6 @@ def image_preview(
     is_url=False,
     set_proxy: str = "",
     set_referer: str = "",
-    qs_console_status=None,
     set_width_in_rc_file: int = 0,
     force_show: bool = force_show_img,
 ):
@@ -289,7 +281,6 @@ def image_preview(
     :param img: opened file, numpy array, PIL.Image, matplotlib fig
     :param set_proxy: set proxy
     :param set_referer: set refer
-    :param qs_console_status: qs终端的状态信息
     :return:
     """
     global force_show_option, has_set_force_show_option
@@ -299,16 +290,15 @@ def image_preview(
             or force_show
             or (
                 not has_set_force_show_option
-                and prompt(
+                and _ask(
                     {
                         "type": "confirm",
-                        "name": "preview_image_on_terminal",
                         "message": "Preview image on this terminal?"
                         if user_lang != "zh"
                         else "确认在该终端预览图片?",
                         "default": False,
                     }
-                )["preview_image_on_terminal"]
+                )
             )
         ):
             has_set_force_show_option = True
@@ -318,31 +308,36 @@ def image_preview(
             force_show_option = True
         if not is_url and (isinstance(img, str) and not os.path.exists(img)):
             is_url = img.startswith("http")
-        if qs_console_status:
-            qs_console_status.stop()
+
         if is_url:
-            from .. import requirePackage
-            from io import BytesIO
+            img_bytes = requirePackage(".NetTools.NormalDL", "normal_dl")(
+                img,
+                set_referer=set_referer,
+                set_proxy=set_proxy,
+                disableStatus=True,
+                write_to_memory=True,
+            )
+
+            if not img_bytes:
+                from .. import qs_error_string
+
+                qs_default_console.print(
+                    qs_error_string,
+                    "Failed to download image" if user_lang != "zh" else "图片下载失败",
+                )
+                return
 
             img = requirePackage("PIL", "Image", "Pillow").open(
-                BytesIO(
-                    requirePackage(".NetTools.NormalDL", "normal_dl")(
-                        img,
-                        set_referer=set_referer,
-                        set_proxy=set_proxy,
-                        disableStatus=True,
-                        write_to_memory=True,
-                    )
-                )
+                requirePackage("io", "BytesIO")(img_bytes)
             )
         elif not is_url and isinstance(img, str) and os.path.exists(img):
-            from .. import requirePackage
-
             img = requirePackage("PIL", "Image", "Pillow").open(img)
 
-        if qs_console_status:
-            qs_console_status.start()
-            qs_console_status.update("计算图片摆放位置")
+        _st = qs_default_status.status
+
+        qs_default_status(
+            "Calculating the position of the image" if user_lang != "zh" else "计算图片摆放位置"
+        ).start()
 
         buf = to_content_buf(img)
         width, height = get_image_shape(buf)
@@ -389,20 +384,23 @@ def image_preview(
                     break
             if height < width:
                 _real_width += 1
-        if qs_console_status:
-            qs_console_status.stop()
+        qs_default_status.stop()
 
         qs_default_console.print(
             " " * int(max((console_width - _real_width) // 2, 0)),
             end="",
         )
 
-        imgcat(buf, width=min(_real_width, console_width), height=_real_height)
-    except Exception as e:
-        if qs_console_status:
-            qs_console_status.stop()
-        from .. import qs_error_string
+        imgcat(
+            buf,
+            width=min(_real_width, console_width),
+            height=_real_height,
+            force_show=force_show_option,
+        )
 
-        # qs_default_console.print(qs_error_string, repr(e))
+        if _st:
+            qs_default_status.start()
+    except Exception as e:
+        qs_default_status.stop()
         qs_default_console.print_exception()
         return
