@@ -1,9 +1,9 @@
 from prompt_toolkit.validation import Validator, ValidationError
 from inquirer_rhy.prompt import prompt
+import os
 import sys
-from rich.console import Console
+from QuickProject import QproDefaultConsole as qs_default_console
 
-qs_default_console = Console()
 system = sys.platform
 if system.startswith("win"):
     dir_char = "\\"
@@ -207,9 +207,9 @@ terminal_font_size = {
 class QsConfig:
     import json
 
-    def __init__(self, configPath, isExists):
+    def __init__(self, configPath):
         self.path = configPath
-        if isExists:
+        if os.path.exists(configPath):
             try:
                 with open(configPath, "r") as f:
                     self.config = QsConfig.json.loads(f.read())
