@@ -8,17 +8,18 @@ Docs for different language:
 import os
 import sys
 
-from rich.prompt import Prompt as qs_default_input
+from QuickProject import QproDefaultStatus as qs_default_status
+from QuickProject import external_exec, _ask
 
 from .NetTools import headers
 from .__cache__ import QsCache
-from .__config__ import QsConfig, dir_char, system, qs_default_console, prompt
+from .__config__ import QsConfig, dir_char, system, qs_default_console
 
 name = "QuickStart_Rhy"
 
-user_root = os.path.expanduser("~") + dir_char
-qs_config = QsConfig(user_root + ".qsrc", os.path.exists(user_root + ".qsrc"))
-qs_cache = QsCache(user_root + ".qs_cache")
+user_root = os.path.expanduser("~")
+qs_config = QsConfig(os.path.join(user_root, ".qsrc"))
+qs_cache = QsCache(os.path.join(user_root, ".qs_cache"))
 
 user_lang = qs_config.basicSelect("default_language")
 user_currency = qs_config.basicSelect("default_currency")
@@ -34,61 +35,6 @@ qs_info_string = f'[bold cyan][{"INFO" if user_lang != "zh" else "提示"}]'
 qs_console_width = qs_default_console.width
 
 
-def external_exec(
-    cmd: str,
-    without_output: bool = False,
-    without_stdout: bool = False,
-    without_stderr: bool = False,
-):
-    """
-    外部执行命令
-
-    :param cmd: 命令
-    :param without_output: 是否不输出
-    :param without_stdout: 是否不输出stdout
-    :param without_stderr: 是否不输出stderr
-    :return: status code, output
-    """
-    from subprocess import Popen, PIPE
-    from concurrent.futures import ThreadPoolExecutor, wait
-
-    class MixContent:
-        def __init__(self):
-            self.content = ""
-
-        def __add__(self, other):
-            self.content += other
-            return self
-
-        def __str__(self):
-            return self.content
-
-    content = MixContent()
-
-    def _output(pipe_name: str, process: Popen, content: MixContent):
-        ignore_status = (
-            without_stdout if pipe_name == "stdout" else without_stderr
-        ) or without_output
-        for line in iter(eval(f"process.{pipe_name}.readline"), ""):
-            if not ignore_status:
-                qs_default_console.print(line.strip())
-            content += line
-
-    pool = ThreadPoolExecutor(2)
-    p = Popen(cmd, shell=True, stdout=PIPE, stderr=PIPE, bufsize=1, encoding="utf-8")
-
-    wait(
-        [
-            pool.submit(_output, "stdout", p, content),
-            pool.submit(_output, "stderr", p, content),
-        ]
-    )
-    pool.shutdown()
-    ret_code = p.wait()
-
-    return ret_code, str(content)
-
-
 def requirePackage(
     pname: str,
     module: str = "",
@@ -121,13 +67,17 @@ def requirePackage(
                 "default": True,
             }
         ):
-            with qs_default_console.status(
-                "Installing..." if user_lang != "zh" else "正在安装..."
-            ):
-                external_exec(
+            with qs_default_status("Installing..." if user_lang != "zh" else "正在安装..."):
+                st, _ = external_exec(
                     f"{set_pip} install {pname if not real_name else real_name} -U",
                     True,
                 )
+            if st:
+                qs_default_console.print(
+                    qs_error_string,
+                    f"Install {pname + (' -> ' + module if module else '')} failed, please install it manually!",
+                )
+                exit(-1)
             if not_exit:
                 exec(f"from {pname} import {module}" if module else f"import {pname}")
             else:
@@ -141,43 +91,6 @@ def requirePackage(
         return eval(f"{module if module else pname}")
 
 
-def _ask(question: dict, timeout: int = 0):
-    if timeout:
-
-        def ask():
-            def handle(signum, frame):
-                raise RuntimeError
-
-            import signal
-
-            try:
-                signal.signal(signal.SIGALRM, handle)
-                signal.alarm(timeout)
-                res = prompt(question)
-                signal.alarm(0)
-                return res
-            except RuntimeError:
-                if dir_char == "/":
-                    os.system("stty echo")
-                qs_default_console.print(
-                    "\n[bold yellow][Warning | 警告][/bold yellow]",
-                    f"Time out & Return | 超时并返回: {question['default'] if 'default' in question else None}",
-                )
-                return question["default"] if "default" in question else None
-
-    else:
-
-        def ask():
-            return prompt(question)[question["name"]]
-
-    try:
-        if "name" not in question:
-            question["name"] = "NoName"
-        return ask()
-    except:
-        exit(0)
-
-
 def cut_string(string: str, length: int) -> list:
     """
     每隔l个字符切分字符串
@@ -298,11 +211,13 @@ def open_url(argv: list = None):
         try:
             url = pyperclip.paste()
         except:
-            url = qs_default_input.ask(
-                "Sorry, but your system is not supported by `pyperclip`\nSo you need input content manually: "
-                if user_lang != "zh"
-                else "抱歉，但是“pyperclip”不支持你的系统\n，所以你需要手动输入内容:",
-                console=qs_default_console,
+            url = _ask(
+                {
+                    "type": "input",
+                    "message": "Sorry, but your system is not supported by `pyperclip`\n  So you need input content manually: "
+                    if user_lang != "zh"
+                    else "抱歉，但是“pyperclip”不支持你的系统\n  所以你需要手动输入内容:",
+                }
             )
         wb.open_new_tab(formatUrl(url))
 
@@ -447,7 +362,7 @@ def qs_print(*argv):
     """
     if not argv:
         argv = sys.argv[2:]
-    if dir_char != "/":
+    if system.startswith("win"):
         win32api = requirePackage("pywin32", "win32api")
         win32print = requirePackage("pywin32", "win32print")
         for file in argv:
@@ -483,7 +398,7 @@ def sas():
                 "default": True,
             }
         ):
-            with qs_default_console.status(
+            with qs_default_status(
                 "Installing SwitchAudioSource..."
                 if user_lang != "zh"
                 else "正在安装 SwitchAudioSource..."
