@@ -10,6 +10,7 @@ from . import (
     user_lang,
     system,
     qs_default_console,
+    qs_default_status,
     qs_error_string,
     qs_info_string,
     qs_warning_string,
@@ -42,11 +43,8 @@ def remove_bg():
             return
         from .API.SimpleAPI import rmbg
 
-        with qs_default_console.status(
-            "Dealing.." if user_lang != "zh" else "处理中.."
-        ) as st:
+        with qs_default_status("Dealing.." if user_lang != "zh" else "处理中.."):
             rmbg(path)
-            st.update(status="Done")
 
 
 def smms():
@@ -82,11 +80,8 @@ def smms():
             return
         from .API.SimpleAPI import smms
 
-        with qs_default_console.status(
-            "Dealing.." if user_lang != "zh" else "处理中.."
-        ) as st:
+        with qs_default_status("Dealing.." if user_lang != "zh" else "处理中.."):
             smms(path)
-            st.update(status="Done")
 
 
 def ali_oss():
@@ -274,7 +269,7 @@ def translate(content: str = None):
 
 def weather():
     """查天气 | Check weather"""
-    from . import headers, dir_char
+    from . import headers
     from .ThreadTools import ThreadFunctionWrapper
     import requests
 
@@ -285,7 +280,7 @@ def weather():
             return
         ct.encoding = "utf-8"
         ct = ct.text.split("\n")
-        if dir_char == "/":
+        if not system.startswith("win"):
             res = ct.copy()
         else:
             import re
@@ -308,12 +303,9 @@ def weather():
     ]
     for i in tls:
         i.start()
-    with qs_default_console.status(
-        "Requesting.." if user_lang != "zh" else "请求中.."
-    ) as st:
+    with qs_default_status("Requesting.." if user_lang != "zh" else "请求中.."):
         for i in tls:
             i.join()
-        st.update(status="Done")
     simple = tls[0].get_res()
     table = tls[1].get_res()
     if simple:
@@ -373,11 +365,8 @@ def largeImage():
         from .API.BaiduCloud import ImageDeal
 
         aip_cli = ImageDeal()
-        with qs_default_console.status(
-            "Dealing.." if user_lang != "zh" else "处理中.."
-        ) as st:
-            aip_cli.largeImage(path, st)
-            st.update(status="Done")
+        with qs_default_status("Dealing.." if user_lang != "zh" else "处理中.."):
+            aip_cli.largeImage(path)
 
 
 def AipNLP():
@@ -449,11 +438,8 @@ def gbc():
     from .API.alapi import garbage_classification
 
     try:
-        with qs_default_console.status(
-            "Requesting data.." if user_lang != "zh" else "请求数据中.."
-        ) as st:
+        with qs_default_status("Requesting data.." if user_lang != "zh" else "请求数据中.."):
             res = garbage_classification(sys.argv[2:])
-            st.update(status="Done")
         qs_default_console.print(res, justify="center")
     except Exception as e:
         qs_default_console.print(qs_error_string, repr(e))
@@ -503,7 +489,8 @@ def short_video_info(son_call=False):
         "cover": "Cover " if user_lang != "zh" else "封面",
         "source": "Source" if user_lang != "zh" else "来源",
     }
-    with qs_default_console.status("正在获取视频信息") as _:
+
+    with qs_default_status("正在获取视频信息"):
         status, res = short_video_info(url.strip("/"))
         if not status:
             qs_default_console.print(qs_info_string, res["title"] + ":" + res["source"])
@@ -593,10 +580,7 @@ def acg():
     from .API.alapi import acg
     from .API.SimpleAPI import acg2
 
-    st = qs_default_console.status(
-        "Requesting data.." if user_lang != "zh" else "请求数据中.."
-    )
-    st.start()
+    qs_default_status("Requesting data.." if user_lang != "zh" else "请求数据中..").start()
     try:
         status, acg_link, width, height = random.choice([acg, acg2])()
         qs_default_console.print(
@@ -611,24 +595,23 @@ def acg():
                 height,
             )
             if "--save" in sys.argv[2:]:
-                from . import dir_char
                 from .NetTools.NormalDL import normal_dl
 
-                st.stop()
                 acg_link = normal_dl(acg_link)  # disable download status for Windows
             from .ImageTools.ImagePreview import image_preview
 
-            st.update(status="Loading image...\n" if user_lang != "zh" else "加载图片中..\n")
+            qs_default_status(
+                status="Loading image...\n" if user_lang != "zh" else "加载图片中..\n"
+            ).start()
             image_preview(
                 open(acg_link) if "--save" in sys.argv[2:] else acg_link,
                 "--save" not in sys.argv[2:],
-                qs_console_status=st,
             )
             return
     except Exception as e:
         qs_default_console.print(qs_error_string, repr(e))
     finally:
-        st.stop()
+        qs_default_status.stop()
 
 
 def bingImg():
@@ -641,10 +624,7 @@ def bingImg():
     """
     from .API.alapi import bingImg
 
-    st = qs_default_console.status(
-        "Requesting data.." if user_lang != "zh" else "请求数据中.."
-    )
-    st.start()
+    qs_default_status("Requesting data.." if user_lang != "zh" else "请求数据中..").start()
 
     try:
         status, acg_link, cprt = bingImg()
@@ -658,20 +638,21 @@ def bingImg():
             if "--save" in sys.argv[2:]:
                 from .NetTools.NormalDL import normal_dl
 
-                st.stop()
+                qs_default_status.stop()
                 acg_link = normal_dl(acg_link)
             from .ImageTools.ImagePreview import image_preview
 
-            st.update(status="Loading image..." if user_lang != "zh" else "加载图片中..")
+            qs_default_status.update(
+                status="Loading image..." if user_lang != "zh" else "加载图片中.."
+            )
             image_preview(
                 open(acg_link) if "--save" in sys.argv[2:] else acg_link,
                 "--save" not in sys.argv[2:],
-                qs_console_status=st,
             )
     except Exception as e:
         qs_default_console.print(qs_error_string, repr(e))
     finally:
-        st.stop()
+        qs_default_status.stop()
 
 
 def preview_html_images():
@@ -699,12 +680,10 @@ def kdCheck():
 
     :return:
     """
-    from .API.alapi import kdCheck
+    from .API.alapi import kdCheck as kdCheckAPI
 
-    with qs_default_console.status(
-        "Requesting data.." if user_lang != "zh" else "请求数据中.."
-    ):
-        status, code, msg = kdCheck(sys.argv[2])
+    with qs_default_status("Requesting data.." if user_lang != "zh" else "请求数据中.."):
+        status, code, msg = kdCheckAPI(sys.argv[2])
         if not status:
             qs_default_console.print(qs_error_string, msg)
             return
@@ -730,32 +709,26 @@ def kdCheck():
         ],
         (
             [
-                "[bold underline red]Unknown:heavy_exclamation_mark:",
-                "[bold underline yellow]In transit:airplane:",
-                "[bold underline green]In delivery:delivery_truck:",
-                "[bold underline bold green]Signed receipt:hearts:",
+                ":heavy_exclamation_mark: [bold underline red]Unknown",
+                ":airplane: [bold underline yellow]In transit",
+                ":delivery_truck: [bold underline green]In delivery",
+                ":hearts: [bold underline bold green]Signed receipt",
             ][code]
             if user_lang != "zh"
             else [
-                "[bold underline red]未知:heavy_exclamation_mark:",
-                "[bold underline yellow]运输中:airplane:",
-                "[bold underline green]派送中:delivery_truck:",
-                "[bold underline magenta]已签收:hearts:",
+                ":heavy_exclamation_mark: [bold underline red]未知",
+                ":airplane: [bold underline yellow]运输中",
+                ":delivery_truck: [bold underline green]派送中",
+                ":hearts: [bold underline magenta]已签收:hearts:",
             ][code]
         )
         + "\n",
     )
-    for info in msg[:-1] if code != 3 else msg:
+    for _id, info in enumerate(msg):
         tb.add_row(
             info["time"],
             Text(table_cell(info["content"], width), justify="full"),
-            "[green]:heavy_check_mark:",
-        )
-    if code != 3:
-        tb.add_row(
-            msg[-1]["time"],
-            Text(table_cell(msg[-1]["content"], width), justify="full"),
-            "[bold yellow]:arrow_left:",
+            "[bold green]:heavy_check_mark:" if _id else "[bold yellow]:arrow_left:",
         )
     qs_default_console.print(tb, justify="center")
 
@@ -772,9 +745,7 @@ def loli():
     from .ImageTools import ImagePreview
     from .NetTools import NormalDL
 
-    with qs_default_console.status(
-        "Requesting data.." if user_lang != "zh" else "请求数据中.."
-    ):
+    with qs_default_status("Requesting data.." if user_lang != "zh" else "请求数据中.."):
         status, msg, data = loli_img()
         if not status:
             qs_default_console.print(qs_error_string, msg)
@@ -814,13 +785,8 @@ def loli():
                 not save_flag,
                 set_proxy=proxy,
                 set_referer="https://i.pximg.net",
-                qs_console_status=qs_default_console.status("展示图片中.."),
             )
 
-        qs_default_console.print(
-            "-" * (qs_default_console.width // 4 * 3), justify="center"
-        )
-
 
 def pinyin():
     from .API.alapi import pinyin
@@ -838,11 +804,8 @@ def pinyin():
                 if user_lang != "zh"
                 else "抱歉，但是“pyperclip”不支持你的系统\n，所以你需要手动输入内容:"
             )
-    with qs_default_console.status(
-        "Requesting data.." if user_lang != "zh" else "请求数据中.."
-    ) as st:
+    with qs_default_status("Requesting data.." if user_lang != "zh" else "请求数据中.."):
         status, res = pinyin(content)
-        st.update(status="Done" if user_lang != "zh" else "请求完成")
     qs_default_console.print(qs_info_string, content)
     qs_default_console.print(qs_info_string if status else qs_error_string, res)
 
@@ -856,10 +819,7 @@ def setu():
 def exchange():
     from .API.alapi import exchange
 
-    st = qs_default_console.status(
-        "Requesting data.." if user_lang != "zh" else "请求数据中.."
-    )
-    st.start()
+    qs_default_status("Requesting data.." if user_lang != "zh" else "请求数据中..").start()
     try:
         status, data = exchange(sys.argv[3], 1)
         qs_default_console.print(
@@ -871,7 +831,7 @@ def exchange():
     except Exception as e:
         qs_default_console.print(qs_error_string, repr(e))
     finally:
-        st.stop()
+        qs_default_status.stop()
 
 
 def zhihuDaily():
@@ -879,13 +839,10 @@ def zhihuDaily():
     from rich.panel import Panel
     from .ImageTools.ImagePreview import image_preview
 
-    st = qs_default_console.status(
-        "Requesting data.." if user_lang != "zh" else "请求数据中.."
-    )
-    st.start()
+    qs_default_status("Requesting data.." if user_lang != "zh" else "请求数据中..").start()
     try:
         status, data = zhihuDaily()
-        st.stop()
+        qs_default_status.stop()
         if not status:
             qs_default_console.log(qs_error_string, data)
             return
@@ -913,7 +870,7 @@ def zhihuDaily():
     except Exception as e:
         qs_default_console.print(qs_error_string, repr(e))
     finally:
-        st.stop()
+        qs_default_status.stop()
 
 
 def wallhaven():
@@ -963,10 +920,8 @@ def wallhaven():
             )
             from .ImageTools.ImagePreview import image_preview
 
-            with qs_default_console.status(
-                "Getting.." if user_lang != "zh" else "获取图片中.."
-            ) as st:
-                image_preview(res["url"], True, qs_console_status=st)
+            with qs_default_status("Getting.." if user_lang != "zh" else "获取图片中.."):
+                image_preview(res["url"], True)
         else:
             from .TuiTools.Table import qs_default_table
 
@@ -1031,7 +986,7 @@ def daily60s():
 
     cur_index = 0
 
-    with qs_default_console.status("showing" if user_lang != "zh" else "展示中") as st:
+    with qs_default_status("showing" if user_lang != "zh" else "展示中"):
 
         def dealSignal(*argv):
             for index in range(cur_index + 1, len(res["news"])):
@@ -1048,16 +1003,16 @@ def daily60s():
                 import os
                 from .NetTools.NormalDL import normal_dl
 
-                st.stop()
                 name = normal_dl(res["image"], set_name="news.png")
-                st.start()
                 qs_default_console.print(
                     "Preview" if user_lang != "zh" else "预览", justify="center"
                 )
                 from .ImageTools.ImagePreview import image_preview
 
-                st.update(status="loading image.." if user_lang != "zh" else "加载图片中..")
-                image_preview(open(name), qs_console_status=st)
+                qs_default_status.update(
+                    status="loading image.." if user_lang != "zh" else "加载图片中.."
+                )
+                image_preview(open(name))
             exit(0)
 
         signal.signal(signal.SIGINT, dealSignal)
@@ -1101,16 +1056,15 @@ def m2t():
         contents = requirePackage("pyperclip", "paste")()
     urls = re.findall("magnet:\?xt=urn:btih:(.*)", contents)
     if len(urls) > 1:
-        from .__config__ import prompt
+        from . import _ask
 
-        url = prompt(
+        url = _ask(
             {
                 "type": "list",
-                "name": "hash",
                 "message": "Select hash code | 选择哈希码:",
                 "choices": urls,
             }
-        )["hash"]
+        )
     else:
         url = urls[0]
     from .API.Lolicon import magnet2torrent
@@ -1130,7 +1084,7 @@ def d2m():
     except IndexError:
         return qs_default_console.print(qs_error_string, "qs d2m <designation>")
 
-    from .__config__ import prompt
+    from . import _ask
     from .API.SimpleAPI import Designation2magnet
 
     copy = requirePackage("pyperclip", "copy", not_ask=True)
@@ -1145,14 +1099,13 @@ def d2m():
         url = searcher.get_magnet(
             infos[
                 choices.index(
-                    prompt(
+                    _ask(
                         {
                             "type": "list",
                             "message": "Select | 选择",
-                            "name": "sub-url",
                             "choices": choices,
                         }
-                    )["sub-url"]
+                    )
                 )
             ][0]
         )
@@ -1244,9 +1197,7 @@ def gpt():
             }
         )
     ) != "exit":
-        with qs_default_console.status(
-            "Thinking..." if user_lang != "zh" else "思考中..."
-        ):
+        with qs_default_status("Thinking..." if user_lang != "zh" else "思考中..."):
             res = chatGPT(prompt)
         qs_default_console.print(
             "[bold green]" + ("Answer" if user_lang != "zh" else "回答") + "[/]\n",
