@@ -13,9 +13,15 @@ def upgrade():
 
     Upgrade qs
     """
-    from . import external_exec, user_pip, qs_default_console, qs_info_string
+    from . import (
+        external_exec,
+        user_pip,
+        qs_default_console,
+        qs_info_string,
+        qs_default_status,
+    )
 
-    with qs_default_console.status("正在更新"):
+    with qs_default_status("正在更新"):
         external_exec(f"{user_pip} install QuickStart-Rhy --upgrade", True)
     qs_default_console.print(qs_info_string, "更新完成")
 
